@@ -71,7 +71,7 @@ class TestUsersController(TestController):
                                      content_type='application/json')
         response = self.app.get(url('user', id='user1@test.com'))
         self.assertEqual(response.status, '200 OK')
-        self.assertDictEqual(json.loads(response.body), {'name':'user1@test.com', 'pubkey':constants.USER1_PUBLIC_KEY})
+        self.assertEqual(json.loads(response.body), {'name':'user1@test.com', 'pubkey':constants.USER1_PUBLIC_KEY})
 
     # def test_show_as_xml(self):
     #     response = self.app.get(url('formatted_user', id=1, format='xml'))
